export declare enum LogLevel {
    ERROR = 0,
    WARN = 1,
    INFO = 2,
    DEBUG = 3
}
export declare enum PublicKeyFormat {
    /**
     * OpenSSH format
     */
    OPENSSH = "openssh",
    /**
     * SSH format
     */
    SSH = "ssh",
    /**
     * PEM format
     */
    PEM = "pem",
    /**
     * PKCS#1 format
     */
    PKCS1 = "pkcs1",
    /**
     * PKCS#8 format
     */
    PKCS8 = "pkcs8",
    /**
     * Raw OpenSSH wire format
     *
     * As CloudFormation cannot handle binary data, if the public key is exposed in the template, the value is base64 encoded
     */
    RFC4253 = "rfc4253",
    /**
     * PuTTY ppk format
     */
    PUTTY = "putty"
}
export declare enum KeyType {
    RSA = "rsa",
    ED25519 = "ed25519"
}
export interface ResourceProperties {
    Name: string;
    StorePublicKey?: 'true' | 'false';
    ExposePublicKey?: 'true' | 'false';
    PublicKey: string;
    SecretPrefix: string;
    Description: string;
    KmsPrivate: string;
    KmsPublic: string;
    KeyType: KeyType;
    PublicKeyFormat: PublicKeyFormat;
    RemoveKeySecretsAfterDays: number;
    StackName: string;
    Tags: Record<string, string>;
    LogLevel?: LogLevel;
}
